pyxmpp2.error.StreamErrorElement

Package pyxmpp2 :: Module error :: Class StreamErrorElement |
[hide private]

# Class StreamErrorElement

Stream error element.

Instance Methods | [hide private]
__init__(self, element_or_cond, text=None, language=None) Initialize an StreamErrorElement object. |
`unicode` |
get_message(self) Get the standard English message for the error. |
Inherited from `ErrorElement`: `add_custom_condition`, `as_xml`, `serialize` Inherited from `ErrorElement` (private): `_from_xml` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| error_qname = ``'``{http://etherx.jabber.org/streams}error``'``
| text_qname = ``'``{http://etherx.jabber.org/streams}text``'``
| cond_qname_prefix = ``'``{urn:ietf:params:xml:ns:xmpp-streams}``'``

Instance Variables | [hide private]
Inherited from `ErrorElement`: `condition`, `custom_condition`, `language`, `text`

Properties | [hide private]
Inherited from `ErrorElement`: `condition_name` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, element_or_cond, text=None, language=None) (Constructor) |
Initialize an StreamErrorElement object. Parameters: `element_or_cond` (`ElementTree.Element` or `unicode`) - XML <error/> element to decode or an error condition name or element. `text` (`unicode`) - optional description to override the default one `language` (`unicode`) - RFC 3066 language tag for the description Overrides: object.__init__

### get_message(self) |
Get the standard English message for the error. Returns: `unicode` the error message.